pub unsafe extern "C" fn sys_multi_mem_blocks_init(
group: *mut sys_multi_mem_blocks_t,
choice_fn: sys_multi_mem_blocks_choice_fn_t,
)Expand description
@brief Initialize multi memory blocks allocator group
Initialize a sys_multi_mem_block struct with the specified choice function. Note that individual allocator must be added later with sys_multi_mem_blocks_add_allocator.
@param group Multi memory blocks allocator structure. @param choice_fn A sys_multi_mem_blocks_choice_fn_t callback used to select the allocator to be used at allocation time