pub unsafe extern "C" fn sys_sfnode_flags_set(
node: *mut sys_sfnode_t,
flags: u8,
)Expand description
@brief Set flags value for an sflist node
Set a flags value for this slist node. The value must fit in the number of bits reported by @ref SYS_SFLIST_FLAG_BITS. These flags will persist even if the node is moved around within a list, removed, or transplanted to a different slist.
@param node A pointer to the node to set the flags on @param flags The flags value to set