uart_irq_is_pending

Function uart_irq_is_pending 

pub unsafe extern "C" fn uart_irq_is_pending(
    dev: *const device,
) -> c_int
@brief Check if any IRQs is pending.

This function must be called in a UART interrupt handler, or its result is undefined. Before calling this function in the interrupt handler, uart_irq_update() must be called otherwise its result may be outdated.

@param dev UART device instance.

@retval 1 An IRQ is pending. @retval 0 An IRQ is not pending. @retval -ENOSYS This function is not implemented. @retval -ENOTSUP API is not enabled.