pub unsafe extern "C" fn uart_irq_tx_ready(
dev: *const device,
) -> c_intExpand description
@brief Check if UART TX buffer can accept bytes
@details Check if UART TX buffer can accept more bytes for transmission (i.e. uart_fifo_fill() will succeed and return non-zero). This function must be called in a UART interrupt handler, or its result is undefined. Before calling this function in the interrupt handler, uart_irq_update() must be called once per the handler invocation.
@param dev UART device instance.
@retval 0 Device is not ready to write a new byte. @return Minimum number of bytes that can be written in a single call to @ref uart_fifo_fill if the device is ready, negative errno value on failure. @retval -ENOSYS Function is not implemented. @retval -ENOTSUP API is not enabled.