uart_rx_disable

Function uart_rx_disable 

pub unsafe extern "C" fn uart_rx_disable(dev: *const device) -> c_int
@brief Disable RX

#UART_RX_BUF_RELEASED event will be generated for every buffer scheduled, after that #UART_RX_DISABLED event will be generated. Additionally, if there is any pending received data, the #UART_RX_RDY event for that data will be generated before the #UART_RX_BUF_RELEASED events.

@param dev UART device instance.

@return 0 on success, negative errno value on failure. @retval -ENOTSUP API is not enabled. @retval -EFAULT There is no active reception.