pub unsafe extern "C" fn uart_tx_u16(
dev: *const device,
buf: *const u16,
len: usize,
timeout: i32,
) -> c_intExpand description
@brief Send given number of datum from buffer through UART.
Function returns immediately and event handler, set using @ref uart_callback_set, is called after transfer is finished.
@param dev UART device instance. @param buf Pointer to wide data transmit buffer. @param len Length of wide data transmit buffer. @param timeout Timeout in milliseconds. Valid only if flow control is enabled. @ref SYS_FOREVER_MS disables timeout.
@return 0 on success, negative errno value on failure. @retval -ENOTSUP API is not enabled. @retval -EBUSY There is already an ongoing transfer.