i2c_target_callbacks

Struct i2c_target_callbacks 

#[repr(C)]
pub struct i2c_target_callbacks { pub write_requested: i2c_target_write_requested_cb_t, pub read_requested: i2c_target_read_requested_cb_t, pub write_received: i2c_target_write_received_cb_t, pub read_processed: i2c_target_read_processed_cb_t, pub stop: i2c_target_stop_cb_t, pub error: i2c_target_error_cb_t, }
@brief Structure providing callbacks to be implemented for devices that supports the I2C target API.

This structure may be shared by multiple devices that implement the same API at different addresses on the bus.

Fields

write_requested: i2c_target_write_requested_cb_t

@copybrief i2c_target_write_requested_cb_t

read_requested: i2c_target_read_requested_cb_t

@copybrief i2c_target_read_requested_cb_t

write_received: i2c_target_write_received_cb_t

@copybrief i2c_target_write_received_cb_t

read_processed: i2c_target_read_processed_cb_t

@copybrief i2c_target_read_processed_cb_t

stop: i2c_target_stop_cb_t

@copybrief i2c_target_stop_cb_t

error: i2c_target_error_cb_t

@copybrief i2c_target_error_cb_t