atomic_t

Type Alias atomic_t 

pub type atomic_t = c_long;
@brief Atomic integer variable.

An atomic variable of this type can be read and modified by threads and ISRs in an uninterruptible manner using the atomic APIs. It is a 32-bit variable on 32-bit machines and a 64-bit variable on 64-bit machines.