pub unsafe extern "C" fn k_thread_runtime_stats_is_enabled(
thread: k_tid_t,
) -> boolExpand description
@brief Check if runtime statistics gathering is enabled for a thread
This routine checks whether the specified thread has enabled runtime statistics.
@param thread ID of thread @return true if usage statistics are enabled for the given thread, otherwise false